@@ -1,9 +1,16 @@
 package Net::DNS;
 #
-# $Id: DNS.pm 373 2005-06-10 10:09:29Z olaf $
+# $Id: DNS.pm 393 2005-07-01 19:21:52Z olaf $
 #
 use strict;
-use bytes;
+
+
+BEGIN { 
+    eval { require bytes; }
+}
+
+
+
 use vars qw(
     $HAVE_XS
     $VERSION
@@ -34,11 +41,12 @@ BEGIN {
     @ISA     = qw(Exporter DynaLoader);
 
     
-    $VERSION = '0.51';
+    $VERSION = '0.52';
     $HAVE_XS = eval { 
 	local $SIG{'__DIE__'} = 'DEFAULT';
 	__PACKAGE__->bootstrap(); 1 
 	} ? 1 : 0;
+
 }
 
 
